@@ -1,3 +1,15 @@
+export interface Ok<T> {
+  variant: "Ok";
+  fields: [T];
+}
+
+export interface Err {
+  variant: "Err";
+  fields: [string];
+}
+
+export type Result<T> = Ok<T> | Err;
+
 export interface Range {
   start: number;
   end: number;
